# animate-wall-eg1.gnu    2004-02-05
# animation of transient temp in plane wall
# Biot = 1.0  Four term solution
###########################################################
# set sample conditions
rho = 1800.0
k = 18.0
cp = 534.0
L = 0.040
#
T_inf = 15.0
h_inf = 450.0
#
T_i = 90.0
#
Bi = h_inf*L/k
##For Bi=1.0
zeta_1 = 0.8603
zeta_2 = 3.4256
zeta_3 = 6.4373
zeta_4 = 9.5293
#
Cfun(z) = 4.0* sin(z)/(2.0*z + sin (2.0*z) )
C_1 = Cfun(zeta_1)
C_2 = Cfun(zeta_2)
C_3 = Cfun(zeta_3)
C_4 = Cfun(zeta_4)
#
alpha = k/(rho*cp)
#
Fo(t) = alpha*t/(L**2)
#
theta(x,t) = C_1 * exp ( - ((zeta_1)**2) * Fo(t) )* cos( (zeta_1)*(x/L)) +\
             C_2 * exp ( - ((zeta_2)**2) * Fo(t) )* cos( (zeta_2)*(x/L)) +\
             C_3 * exp ( - ((zeta_3)**2) * Fo(t) )* cos( (zeta_3)*(x/L)) +\
             C_4 * exp ( - ((zeta_4)**2) * Fo(t) )* cos( (zeta_4)*(x/L))
#
temp(x,t) = theta(x,t)*(T_i - T_inf) + T_inf
#
set title "Temperature: Plane Wall with Bi = 1.0"
set key 0.03,80
set xlabel "x distance [m]"
set xrange [0:L]
set xtics nomirror
set ylabel "Temperature [deg C]"
set yrange [10:100]
set ytics nomirror 10.0,5.0,100.
set mytics 5
#
set x2range [0.0:300]
set x2label "Elapsed time [s]"
set y2range [0:1]
set x2tics  nomirror 0.0,60.,480.
set noy2tics
#
hbar(x)=0.97
x_lft_et = 0.0
p_elapsed_time(x,t) = (( x_lft_et < x)&&(x<= t )) ? ( hbar(x) ):sqrt(-1)
#
t=0
#-time step------#
dtime = 0.5
#----------------#
#
set sample 1000
set dummy x
#
set nolabel
set label 1 "T_i = 90 [deg C]" at 0.025,55
set label 2 "h_inf = 500 [W/m**2 K]" at 0.025,50.0
set label 3 "T_inf = 15  [deg C]" at 0.025,45.0
set label 4 "dtime = 0.5 [s]" at 0.025,40.0
#
plot T_i w lines lt 4 lw 2, T_inf w lines lw 1, \
     temp(x,t) with lines lt 3 lw 3, \
     p_elapsed_time(x,t) axes x2y2  title "Elapsed time" with lines lt 1 lw 8
#
#
limit_iterations=599 # limits number of iterations if nonzero
#
if (!limit_iterations) print "Stop the following animation with ctrl-c"

pause -1 "Press a key to start the animation..."

iteration_count=0
load "do-time-step.gnu"
